@@ -1,114 +1,114 @@
 var dir_2483050b711c1829a6434006d0beb10c =
 [
-    [ "bufferDescriptor.h", "a00596.html", [
+    [ "bufferDescriptor.h", "a00605.html", [
       [ "BufferDescriptor", "a00929.html", "a00929" ]
     ] ],
-    [ "clEvaluator.h", "a00599.html", [
+    [ "clEvaluator.h", "a00632.html", [
       [ "CLStencilTable", "a00933.html", "a00933" ],
       [ "CLEvaluator", "a00937.html", "a00937" ]
     ] ],
-    [ "clPatchTable.h", "a00602.html", [
+    [ "clPatchTable.h", "a00611.html", [
       [ "CLPatchTable", "a00941.html", "a00941" ]
     ] ],
-    [ "clVertexBuffer.h", "a00605.html", [
+    [ "clVertexBuffer.h", "a00617.html", [
       [ "CLVertexBuffer", "a00945.html", "a00945" ]
     ] ],
-    [ "cpuD3D11VertexBuffer.h", "a00608.html", [
+    [ "cpuD3D11VertexBuffer.h", "a00614.html", [
       [ "CpuD3D11VertexBuffer", "a00949.html", "a00949" ]
     ] ],
-    [ "cpuEvaluator.h", "a00611.html", [
+    [ "cpuEvaluator.h", "a00668.html", [
       [ "CpuEvaluator", "a00953.html", null ]
     ] ],
-    [ "cpuGLVertexBuffer.h", "a00614.html", [
+    [ "cpuGLVertexBuffer.h", "a00671.html", [
       [ "CpuGLVertexBuffer", "a00957.html", "a00957" ]
     ] ],
-    [ "cpuPatchTable.h", "a00617.html", [
+    [ "cpuPatchTable.h", "a00566.html", [
       [ "CpuPatchTable", "a00961.html", "a00961" ]
     ] ],
-    [ "cpuVertexBuffer.h", "a00620.html", [
+    [ "cpuVertexBuffer.h", "a00629.html", [
       [ "CpuVertexBuffer", "a00965.html", "a00965" ]
     ] ],
-    [ "cudaEvaluator.h", "a00623.html", [
+    [ "cudaEvaluator.h", "a00656.html", [
       [ "CudaStencilTable", "a00969.html", "a00969" ],
       [ "CudaEvaluator", "a00973.html", null ]
     ] ],
-    [ "cudaPatchTable.h", "a00626.html", [
+    [ "cudaPatchTable.h", "a00599.html", [
       [ "CudaPatchTable", "a00977.html", "a00977" ]
     ] ],
-    [ "cudaVertexBuffer.h", "a00629.html", [
+    [ "cudaVertexBuffer.h", "a00635.html", [
       [ "CudaVertexBuffer", "a00981.html", "a00981" ]
     ] ],
-    [ "d3d11ComputeEvaluator.h", "a00632.html", [
+    [ "d3d11ComputeEvaluator.h", "a00602.html", [
       [ "D3D11StencilTable", "a00985.html", "a00985" ],
       [ "D3D11ComputeEvaluator", "a00989.html", "a00989" ]
     ] ],
-    [ "d3d11LegacyGregoryPatchTable.h", "a00635.html", [
+    [ "d3d11LegacyGregoryPatchTable.h", "a00560.html", [
       [ "D3D11LegacyGregoryPatchTable", "a00993.html", "a00993" ]
     ] ],
-    [ "d3d11Mesh.h", "a00638.html", "a00638" ],
-    [ "d3d11PatchTable.h", "a00641.html", [
+    [ "d3d11Mesh.h", "a00647.html", "a00647" ],
+    [ "d3d11PatchTable.h", "a00644.html", [
       [ "D3D11PatchTable", "a00997.html", "a00997" ]
     ] ],
-    [ "d3d11VertexBuffer.h", "a00644.html", [
+    [ "d3d11VertexBuffer.h", "a00554.html", [
       [ "D3D11VertexBuffer", "a01001.html", "a01001" ]
     ] ],
-    [ "glComputeEvaluator.h", "a00647.html", [
+    [ "glComputeEvaluator.h", "a00653.html", [
       [ "GLStencilTableSSBO", "a01005.html", "a01005" ],
       [ "GLComputeEvaluator", "a01009.html", "a01009" ]
     ] ],
-    [ "glLegacyGregoryPatchTable.h", "a00650.html", [
+    [ "glLegacyGregoryPatchTable.h", "a00551.html", [
       [ "GLLegacyGregoryPatchTable", "a01021.html", "a01021" ]
     ] ],
-    [ "glMesh.h", "a00653.html", "a00653" ],
-    [ "glPatchTable.h", "a00656.html", [
+    [ "glMesh.h", "a00581.html", "a00581" ],
+    [ "glPatchTable.h", "a00563.html", [
       [ "GLPatchTable", "a01025.html", "a01025" ]
     ] ],
-    [ "glslPatchShaderSource.h", "a00659.html", [
+    [ "glslPatchShaderSource.h", "a00575.html", [
       [ "GLSLPatchShaderSource", "a01029.html", null ]
     ] ],
-    [ "glVertexBuffer.h", "a00662.html", [
+    [ "glVertexBuffer.h", "a00572.html", [
       [ "GLVertexBuffer", "a01033.html", "a01033" ]
     ] ],
-    [ "glXFBEvaluator.h", "a00665.html", [
+    [ "glXFBEvaluator.h", "a00596.html", [
       [ "GLStencilTableTBO", "a01037.html", "a01037" ],
       [ "GLXFBEvaluator", "a01041.html", "a01041" ]
     ] ],
-    [ "hlslPatchShaderSource.h", "a00668.html", [
+    [ "hlslPatchShaderSource.h", "a00608.html", [
       [ "HLSLPatchShaderSource", "a01053.html", null ]
     ] ],
-    [ "mesh.h", "a00671.html", "a00671" ],
-    [ "mtlCommon.h", "a00674.html", [
+    [ "mesh.h", "a00662.html", "a00662" ],
+    [ "mtlCommon.h", "a00587.html", [
       [ "MTLContext", "a01073.html", "a01073" ]
     ] ],
-    [ "mtlComputeEvaluator.h", "a00677.html", [
+    [ "mtlComputeEvaluator.h", "a00620.html", [
       [ "MTLStencilTable", "a01077.html", "a01077" ],
       [ "MTLComputeEvaluator", "a01081.html", "a01081" ]
     ] ],
-    [ "mtlLegacyGregoryPatchTable.h", "a00680.html", [
+    [ "mtlLegacyGregoryPatchTable.h", "a00665.html", [
       [ "MTLLegacyGregoryPatchTable", "a01085.html", "a01085" ]
     ] ],
-    [ "mtlMesh.h", "a00683.html", "a00683" ],
-    [ "mtlPatchShaderSource.h", "a00686.html", [
+    [ "mtlMesh.h", "a00593.html", "a00593" ],
+    [ "mtlPatchShaderSource.h", "a00590.html", [
       [ "MTLPatchShaderSource", "a01089.html", null ]
     ] ],
-    [ "mtlPatchTable.h", "a00689.html", [
+    [ "mtlPatchTable.h", "a00623.html", [
       [ "MTLPatchTable", "a01093.html", "a01093" ]
     ] ],
-    [ "mtlVertexBuffer.h", "a00692.html", [
+    [ "mtlVertexBuffer.h", "a00578.html", [
       [ "CPUMTLVertexBuffer", "a01097.html", "a01097" ]
     ] ],
-    [ "nonCopyable.h", "a00695.html", [
-      [ "NonCopyable", "a01101.html", "a01101" ]
+    [ "nonCopyable.h", "a00641.html", [
+      [ "NonCopyable< T >", "a01101.html", "a01101" ]
     ] ],
-    [ "ompEvaluator.h", "a00698.html", [
+    [ "ompEvaluator.h", "a00569.html", [
       [ "OmpEvaluator", "a01105.html", null ]
     ] ],
-    [ "ompKernel.h", "a00701.html", "a00701" ],
-    [ "opencl.h", "a00704.html", null ],
-    [ "opengl.h", "a00707.html", null ],
-    [ "tbbEvaluator.h", "a00710.html", [
+    [ "ompKernel.h", "a00659.html", "a00659" ],
+    [ "opencl.h", "a00557.html", null ],
+    [ "opengl.h", "a00584.html", null ],
+    [ "tbbEvaluator.h", "a00650.html", [
       [ "TbbEvaluator", "a01109.html", null ]
     ] ],
-    [ "tbbKernel.h", "a00713.html", "a00713" ],
-    [ "types.h", "a01301.html", "a01301" ]
+    [ "tbbKernel.h", "a00626.html", "a00626" ],
+    [ "types.h", "a01313.html", "a01313" ]
 ];
\ No newline at end of file
